Crate cosmian_findex_server

Crate cosmian_findex_server 

The lib is mostly useful for the CLI tests but since it is declared, all the modules in other Files will be resolved against the lib. So everything is exported

Re-exports

pub use database::FINDEX_DATASETS_TABLE_NAME;
pub use database::FINDEX_MEMORY_TABLE_NAME;
pub use database::FINDEX_PERMISSIONS_TABLE_NAME;

Modules

config
core
database
error
findex_server
middlewares
routes

Macros

findex_server_ensure
Return early with an error if a condition is not satisfied.
findex_server_error
Construct a server error from a string.
server_bail
Return early with an error if a condition is not satisfied.