The lib is mostly useful for the CLI tests but since it is declared, all the modules in other Files will be resolved against the lib. So everything is exported
Re-exports
pub use database::FINDEX_DATASETS_TABLE_NAME;pub use database::FINDEX_MEMORY_TABLE_NAME;pub use database::FINDEX_PERMISSIONS_TABLE_NAME;
Modules
Macros
- findex_
server_ ensure - Return early with an error if a condition is not satisfied.
- findex_
server_ error - Construct a server error from a string.
- server_
bail - Return early with an error if a condition is not satisfied.